@@ -238,12 +238,12 @@ is_capital_sensitive (GtkCellLayout   *cell_layout,
 }
 
 static void
-fill_combo_entry (GtkWidget *entry)
+fill_combo_entry (GtkWidget *combo)
 {
-  gtk_combo_box_append_text (GTK_COMBO_BOX (entry), "One");
-  gtk_combo_box_append_text (GTK_COMBO_BOX (entry), "Two");
-  gtk_combo_box_append_text (GTK_COMBO_BOX (entry), "2\302\275");
-  gtk_combo_box_append_text (GTK_COMBO_BOX (entry), "Three");
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), "One");
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), "Two");
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), "2\302\275");
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), "Three");
 }
 
 
@@ -281,18 +281,18 @@ G_DEFINE_TYPE_WITH_CODE (MaskEntry, mask_entry, GTK_TYPE_ENTRY,
 static void
 mask_entry_set_background (MaskEntry *entry)
 {
-  static const GdkColor error_color = { 0, 65535, 60000, 60000 };
+  static const GdkRGBA error_color = { 1.0, 0.9, 0.9, 1.0 };
 
   if (entry->mask)
     {
       if (!g_regex_match_simple (entry->mask, gtk_entry_get_text (GTK_ENTRY (entry)), 0, 0))
 	{
-	  gtk_widget_modify_base (GTK_WIDGET (entry), GTK_STATE_NORMAL, &error_color);
+	  gtk_widget_override_color (GTK_WIDGET (entry), 0, &error_color);
 	  return;
 	}
     }
 
-  gtk_widget_modify_base (GTK_WIDGET (entry), GTK_STATE_NORMAL, NULL);
+  gtk_widget_override_color (GTK_WIDGET (entry), 0, NULL);
 }
 
 
@@ -345,7 +345,7 @@ do_combobox (GtkWidget *do_widget)
     
     gtk_container_set_border_width (GTK_CONTAINER (window), 10);
 
-    vbox = gtk_vbox_new (FALSE, 2);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
     gtk_container_add (GTK_CONTAINER (window), vbox);
 
     /* A combobox demonstrating cell renderers, separators and
@@ -354,7 +354,7 @@ do_combobox (GtkWidget *do_widget)
     frame = gtk_frame_new ("Some stock icons");
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
     
-    box = gtk_vbox_new (FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_set_border_width (GTK_CONTAINER (box), 5);
     gtk_container_add (GTK_CONTAINER (frame), box);
     
@@ -395,7 +395,7 @@ do_combobox (GtkWidget *do_widget)
     frame = gtk_frame_new ("Where are we ?");
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 
-    box = gtk_vbox_new (FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_set_border_width (GTK_CONTAINER (box), 5);
     gtk_container_add (GTK_CONTAINER (frame), box);
     
@@ -424,11 +424,11 @@ do_combobox (GtkWidget *do_widget)
     frame = gtk_frame_new ("Editable");
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
     
-    box = gtk_vbox_new (FALSE, 0);
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_set_border_width (GTK_CONTAINER (box), 5);
     gtk_container_add (GTK_CONTAINER (frame), box);
     
-    combo = gtk_combo_box_entry_new_text ();
+    combo = gtk_combo_box_text_new_with_entry ();
     fill_combo_entry (combo);
     gtk_container_add (GTK_CONTAINER (box), combo);
     
@@ -437,7 +437,26 @@ do_combobox (GtkWidget *do_widget)
      
     gtk_container_remove (GTK_CONTAINER (combo), gtk_bin_get_child (GTK_BIN (combo)));
     gtk_container_add (GTK_CONTAINER (combo), entry);
-  
+
+    /* A combobox with string IDs */
+    frame = gtk_frame_new ("String IDs");
+    gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+
+    box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+    gtk_container_set_border_width (GTK_CONTAINER (box), 5);
+    gtk_container_add (GTK_CONTAINER (frame), box);
+
+    combo = gtk_combo_box_text_new ();
+    gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combo), "never", "Not visible");
+    gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combo), "when-active", "Visible when active");
+    gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combo), "always", "Always visible");
+    gtk_container_add (GTK_CONTAINER (box), combo);
+
+    entry = gtk_entry_new ();
+    g_object_bind_property (combo, "active-id",
+                            entry, "text",
+                            G_BINDING_BIDIRECTIONAL);
+    gtk_container_add (GTK_CONTAINER (box), entry);
   }
 
   if (!gtk_widget_get_visible (window))
