@@ -183,10 +183,12 @@ do_ui_manager (GtkWidget *do_widget)
 
       ui = gtk_ui_manager_new ();
       gtk_ui_manager_insert_action_group (ui, actions, 0);
+      g_object_unref (actions);
       gtk_window_add_accel_group (GTK_WINDOW (window), 
 				  gtk_ui_manager_get_accel_group (ui));
       gtk_window_set_title (GTK_WINDOW (window), "UI Manager");
       gtk_container_set_border_width (GTK_CONTAINER (window), 0);
+
       
       if (!gtk_ui_manager_add_ui_from_string (ui, ui_info, -1, &error))
 	{
@@ -194,7 +196,7 @@ do_ui_manager (GtkWidget *do_widget)
 	  g_error_free (error);
 	}
 
-      box1 = gtk_vbox_new (FALSE, 0);
+      box1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
       gtk_container_add (GTK_CONTAINER (window), box1);
       
       gtk_box_pack_start (GTK_BOX (box1),
@@ -207,11 +209,11 @@ do_ui_manager (GtkWidget *do_widget)
       gtk_box_pack_start (GTK_BOX (box1), label, TRUE, TRUE, 0);
 
 
-      separator = gtk_hseparator_new ();
+      separator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
       gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, TRUE, 0);
 
 
-      box2 = gtk_vbox_new (FALSE, 10);
+      box2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
       gtk_container_set_border_width (GTK_CONTAINER (box2), 10);
       gtk_box_pack_start (GTK_BOX (box1), box2, FALSE, TRUE, 0);
 
@@ -219,10 +221,11 @@ do_ui_manager (GtkWidget *do_widget)
       g_signal_connect_swapped (button, "clicked",
 				G_CALLBACK (gtk_widget_destroy), window);
       gtk_box_pack_start (GTK_BOX (box2), button, TRUE, TRUE, 0);
-      GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+      gtk_widget_set_can_default (button, TRUE);
       gtk_widget_grab_default (button);
 
       gtk_widget_show_all (window);
+      g_object_unref (ui);
     }
   else
     {
