@@ -33,42 +33,12 @@
 
 #include <gdk/gdkcursor.h>
 #include <gdk/gdkprivate.h>
-#include <gdk/x11/gdkwindow-x11.h>
-#include <gdk/x11/gdkpixmap-x11.h>
-#include <gdk/x11/gdkdisplay-x11.h>
-
-#include "gdkinternals.h"
-
-#include "config.h"
-
-#define GDK_TYPE_GC_X11              (_gdk_gc_x11_get_type ())
-#define GDK_GC_X11(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GDK_TYPE_GC_X11, GdkGCX11))
-#define GDK_GC_X11_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), GDK_TYPE_GC_X11, GdkGCX11Class))
-#define GDK_IS_GC_X11(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), GDK_TYPE_GC_X11))
-#define GDK_IS_GC_X11_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GDK_TYPE_GC_X11))
-#define GDK_GC_X11_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), GDK_TYPE_GC_X11, GdkGCX11Class))
+#include <gdk/gdkinternals.h>
+#include "gdkwindow-x11.h"
+#include "gdkdisplay-x11.h"
+#include <cairo-xlib.h>
 
 typedef struct _GdkCursorPrivate       GdkCursorPrivate;
-typedef struct _GdkVisualPrivate       GdkVisualPrivate;
-typedef struct _GdkGCX11      GdkGCX11;
-typedef struct _GdkGCX11Class GdkGCX11Class;
-
-struct _GdkGCX11
-{
-  GdkGC parent_instance;
-  
-  GC xgc;
-  GdkScreen *screen;
-  guint16 dirty_mask;
-  guint have_clip_region : 1;
-  guint have_clip_mask : 1;
-  guint depth : 8;
-};
-
-struct _GdkGCX11Class
-{
-  GdkGCClass parent_class;
-};
 
 struct _GdkCursorPrivate
 {
@@ -79,13 +49,10 @@ struct _GdkCursorPrivate
   guint serial;
 };
 
-struct _GdkVisualPrivate
-{
-  GdkVisual visual;
-  Visual *xvisual;
-  GdkScreen *screen;
-};
+void _gdk_x11_error_handler_push (void);
+void _gdk_x11_error_handler_pop  (void);
 
+Colormap _gdk_visual_get_x11_colormap (GdkVisual *visual);
 
 void _gdk_xid_table_insert (GdkDisplay *display,
 			    XID        *xid,
@@ -98,24 +65,6 @@ gint _gdk_send_xevent      (GdkDisplay *display,
 			    glong       event_mask,
 			    XEvent     *event_send);
 
-GType _gdk_gc_x11_get_type (void);
-
-gboolean _gdk_x11_have_render           (GdkDisplay *display);
-
-GdkGC *_gdk_x11_gc_new                  (GdkDrawable     *drawable,
-					 GdkGCValues     *values,
-					 GdkGCValuesMask  values_mask);
-
-GdkImage *_gdk_x11_copy_to_image       (GdkDrawable *drawable,
-					GdkImage    *image,
-					gint         src_x,
-					gint         src_y,
-					gint         dest_x,
-					gint         dest_y,
-					gint         width,
-					gint         height);
-Pixmap   _gdk_x11_image_get_shm_pixmap (GdkImage    *image);
-
 /* Routines from gdkgeometry-x11.c */
 void _gdk_window_move_resize_child (GdkWindow     *window,
                                     gint           x,
@@ -128,8 +77,7 @@ void _gdk_window_process_expose    (GdkWindow     *window,
 
 gboolean _gdk_x11_window_queue_antiexpose  (GdkWindow *window,
 					    cairo_region_t *area);
-void     _gdk_x11_window_queue_translation (GdkWindow *window,
-					    GdkGC     *gc,
+void     _gdk_x11_window_translate         (GdkWindow *window,
 					    cairo_region_t *area,
 					    gint       dx,
 					    gint       dy);
@@ -161,8 +109,6 @@ void _gdk_keymap_add_virtual_modifiers_compat (GdkKeymap       *keymap,
 gboolean _gdk_keymap_key_is_modifier   (GdkKeymap       *keymap,
 					guint            keycode);
 
-GC _gdk_x11_gc_flush (GdkGC *gc);
-
 void _gdk_x11_initialize_locale (void);
 
 void _gdk_xgrab_check_unmap        (GdkWindow *window,
@@ -183,10 +129,6 @@ void _gdk_events_uninit         (GdkDisplay *display);
 void _gdk_windowing_window_init (GdkScreen *screen);
 void _gdk_visual_init           (GdkScreen *screen);
 void _gdk_dnd_init		(GdkDisplay *display);
-void _gdk_windowing_image_init  (GdkDisplay *display);
-
-PangoRenderer *_gdk_x11_renderer_get (GdkDrawable *drawable,
-				      GdkGC       *gc);
 
 void _gdk_x11_cursor_update_theme (GdkCursor *cursor);
 void _gdk_x11_cursor_display_finalize (GdkDisplay *display);
@@ -197,26 +139,22 @@ gboolean _gdk_x11_get_xft_setting (GdkScreen   *screen,
 
 GdkGrabStatus _gdk_x11_convert_grab_status (gint status);
 
+cairo_surface_t * _gdk_x11_window_create_bitmap_surface (GdkWindow *window,
+                                                         int        width,
+                                                         int        height);
 
-extern GdkDrawableClass  _gdk_x11_drawable_class;
 extern gboolean	         _gdk_use_xshm;
 extern const int         _gdk_nenvent_masks;
 extern const int         _gdk_event_mask_table[];
 extern GdkAtom		 _gdk_selection_property;
 extern gboolean          _gdk_synchronize;
 
-#define GDK_PIXMAP_SCREEN(pix)	      (GDK_DRAWABLE_IMPL_X11 (((GdkPixmapObject *)pix)->impl)->screen)
-#define GDK_PIXMAP_DISPLAY(pix)       (GDK_SCREEN_X11 (GDK_PIXMAP_SCREEN (pix))->display)
-#define GDK_PIXMAP_XROOTWIN(pix)      (GDK_SCREEN_X11 (GDK_PIXMAP_SCREEN (pix))->xroot_window)
-#define GDK_DRAWABLE_DISPLAY(win)     (GDK_IS_WINDOW (win) ? GDK_WINDOW_DISPLAY (win) : GDK_PIXMAP_DISPLAY (win))
-#define GDK_DRAWABLE_SCREEN(win)      (GDK_IS_WINDOW (win) ? GDK_WINDOW_SCREEN (win) : GDK_PIXMAP_SCREEN (win))
-#define GDK_DRAWABLE_XROOTWIN(win)    (GDK_IS_WINDOW (win) ? GDK_WINDOW_XROOTWIN (win) : GDK_PIXMAP_XROOTWIN (win))
 #define GDK_SCREEN_DISPLAY(screen)    (GDK_SCREEN_X11 (screen)->display)
 #define GDK_SCREEN_XROOTWIN(screen)   (GDK_SCREEN_X11 (screen)->xroot_window)
-#define GDK_WINDOW_SCREEN(win)	      (GDK_DRAWABLE_IMPL_X11 (((GdkWindowObject *)win)->impl)->screen)
+#define GDK_WINDOW_SCREEN(win)	      (gdk_window_get_screen (win))
 #define GDK_WINDOW_DISPLAY(win)       (GDK_SCREEN_X11 (GDK_WINDOW_SCREEN (win))->display)
 #define GDK_WINDOW_XROOTWIN(win)      (GDK_SCREEN_X11 (GDK_WINDOW_SCREEN (win))->xroot_window)
 #define GDK_GC_DISPLAY(gc)            (GDK_SCREEN_DISPLAY (GDK_GC_X11(gc)->screen))
-#define GDK_WINDOW_IS_X11(win)        (GDK_IS_WINDOW_IMPL_X11 (((GdkWindowObject *)win)->impl))
+#define GDK_WINDOW_IS_X11(win)        (GDK_IS_WINDOW_IMPL_X11 ((win)->impl))
 
 #endif /* __GDK_PRIVATE_X11_H__ */
