@@ -27,7 +27,6 @@
 
 #include "gtklabel.h"
 #include "gtkbuildable.h"
-#include "gtksizerequest.h"
 #include "gtkcontainer.h"
 #include "gtkmarshalers.h"
 #include "gtkmain.h"
@@ -79,16 +78,15 @@ static void gtk_expander_get_property (GObject          *object,
 				       GValue           *value,
 				       GParamSpec       *pspec);
 
-static void gtk_expander_destroy (GtkObject *object);
-
+static void     gtk_expander_destroy        (GtkWidget        *widget);
 static void     gtk_expander_realize        (GtkWidget        *widget);
 static void     gtk_expander_unrealize      (GtkWidget        *widget);
 static void     gtk_expander_size_allocate  (GtkWidget        *widget,
 					     GtkAllocation    *allocation);
 static void     gtk_expander_map            (GtkWidget        *widget);
 static void     gtk_expander_unmap          (GtkWidget        *widget);
-static gboolean gtk_expander_expose         (GtkWidget        *widget,
-					     GdkEventExpose   *event);
+static gboolean gtk_expander_draw           (GtkWidget        *widget,
+					     cairo_t          *cr);
 static gboolean gtk_expander_button_press   (GtkWidget        *widget,
 					     GdkEventButton   *event);
 static gboolean gtk_expander_button_release (GtkWidget        *widget,
@@ -134,53 +132,47 @@ static void gtk_expander_buildable_add_child      (GtkBuildable *buildable,
 						   const gchar  *type);
 
 
-/* GtkSizeRequest */
-static void  gtk_expander_size_request_init     (GtkSizeRequestIface *iface);
-static void  gtk_expander_get_width             (GtkSizeRequest      *widget,
-						 gint                *minimum_size,
-						 gint                *natural_size);
-static void  gtk_expander_get_height            (GtkSizeRequest      *widget,
-						 gint                *minimum_size,
-						 gint                *natural_size);
-static void  gtk_expander_get_height_for_width  (GtkSizeRequest      *layout,
-						 gint                 width,
-						 gint                *minimum_height,
-						 gint                *natural_height);
-static void  gtk_expander_get_width_for_height  (GtkSizeRequest      *layout,
-						 gint                 width,
-						 gint                *minimum_height,
-						 gint                *natural_height);
+/* GtkWidget      */
+static void  gtk_expander_get_preferred_width             (GtkWidget           *widget,
+                                                           gint                *minimum_size,
+                                                           gint                *natural_size);
+static void  gtk_expander_get_preferred_height            (GtkWidget           *widget,
+                                                           gint                *minimum_size,
+                                                           gint                *natural_size);
+static void  gtk_expander_get_preferred_height_for_width  (GtkWidget           *layout,
+                                                           gint                 width,
+                                                           gint                *minimum_height,
+                                                           gint                *natural_height);
+static void  gtk_expander_get_preferred_width_for_height  (GtkWidget           *layout,
+                                                           gint                 width,
+                                                           gint                *minimum_height,
+                                                           gint                *natural_height);
 
 G_DEFINE_TYPE_WITH_CODE (GtkExpander, gtk_expander, GTK_TYPE_BIN,
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
-						gtk_expander_buildable_init)
-                         G_IMPLEMENT_INTERFACE (GTK_TYPE_SIZE_REQUEST,
-                                                gtk_expander_size_request_init))
+						gtk_expander_buildable_init))
 
 static void
 gtk_expander_class_init (GtkExpanderClass *klass)
 {
   GObjectClass *gobject_class;
-  GtkObjectClass *object_class;
   GtkWidgetClass *widget_class;
   GtkContainerClass *container_class;
 
   gobject_class   = (GObjectClass *) klass;
-  object_class    = (GtkObjectClass *) klass;
   widget_class    = (GtkWidgetClass *) klass;
   container_class = (GtkContainerClass *) klass;
 
   gobject_class->set_property = gtk_expander_set_property;
   gobject_class->get_property = gtk_expander_get_property;
 
-  object_class->destroy = gtk_expander_destroy;
-
+  widget_class->destroy              = gtk_expander_destroy;
   widget_class->realize              = gtk_expander_realize;
   widget_class->unrealize            = gtk_expander_unrealize;
   widget_class->size_allocate        = gtk_expander_size_allocate;
   widget_class->map                  = gtk_expander_map;
   widget_class->unmap                = gtk_expander_unmap;
-  widget_class->expose_event         = gtk_expander_expose;
+  widget_class->draw                 = gtk_expander_draw;
   widget_class->button_press_event   = gtk_expander_button_press;
   widget_class->button_release_event = gtk_expander_button_release;
   widget_class->enter_notify_event   = gtk_expander_enter_notify;
@@ -190,6 +182,10 @@ gtk_expander_class_init (GtkExpanderClass *klass)
   widget_class->state_changed        = gtk_expander_state_changed;
   widget_class->drag_motion          = gtk_expander_drag_motion;
   widget_class->drag_leave           = gtk_expander_drag_leave;
+  widget_class->get_preferred_width            = gtk_expander_get_preferred_width;
+  widget_class->get_preferred_height           = gtk_expander_get_preferred_height;
+  widget_class->get_preferred_height_for_width = gtk_expander_get_preferred_height_for_width;
+  widget_class->get_preferred_width_for_height = gtk_expander_get_preferred_width_for_height;
 
   container_class->add    = gtk_expander_add;
   container_class->remove = gtk_expander_remove;
@@ -414,23 +410,25 @@ gtk_expander_get_property (GObject    *object,
 }
 
 static void
-gtk_expander_destroy (GtkObject *object)
+gtk_expander_destroy (GtkWidget *widget)
 {
-  GtkExpanderPrivate *priv = GTK_EXPANDER (object)->priv;
-  
+  GtkExpanderPrivate *priv = GTK_EXPANDER (widget)->priv;
+
   if (priv->animation_timeout)
     {
       g_source_remove (priv->animation_timeout);
       priv->animation_timeout = 0;
     }
-  
-  GTK_OBJECT_CLASS (gtk_expander_parent_class)->destroy (object);
+
+  GTK_WIDGET_CLASS (gtk_expander_parent_class)->destroy (widget);
 }
 
 static void
 gtk_expander_realize (GtkWidget *widget)
 {
+  GtkAllocation allocation;
   GtkExpanderPrivate *priv;
+  GdkWindow *window;
   GdkWindowAttr attributes;
   gint attributes_mask;
   gint border_width;
@@ -438,6 +436,7 @@ gtk_expander_realize (GtkWidget *widget)
   gint label_height;
 
   priv = GTK_EXPANDER (widget)->priv;
+
   gtk_widget_set_realized (widget, TRUE);
 
   border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
@@ -448,16 +447,19 @@ gtk_expander_realize (GtkWidget *widget)
     {
       GtkRequisition label_requisition;
 
-      gtk_widget_get_child_requisition (priv->label_widget, &label_requisition);
+      gtk_widget_get_preferred_size (priv->label_widget,
+                                     &label_requisition, NULL);
       label_height = label_requisition.height;
     }
   else
     label_height = 0;
 
+  gtk_widget_get_allocation (widget, &allocation);
+
   attributes.window_type = GDK_WINDOW_CHILD;
-  attributes.x = widget->allocation.x + border_width;
-  attributes.y = widget->allocation.y + border_width;
-  attributes.width = MAX (widget->allocation.width - 2 * border_width, 1);
+  attributes.x = allocation.x + border_width;
+  attributes.y = allocation.y + border_width;
+  attributes.width = MAX (allocation.width - 2 * border_width, 1);
   attributes.height = MAX (expander_rect.height, label_height - 2 * border_width);
   attributes.wclass = GDK_INPUT_ONLY;
   attributes.event_mask = gtk_widget_get_events (widget)     |
@@ -468,14 +470,15 @@ gtk_expander_realize (GtkWidget *widget)
 
   attributes_mask = GDK_WA_X | GDK_WA_Y;
 
-  widget->window = gtk_widget_get_parent_window (widget);
-  g_object_ref (widget->window);
+  window = gtk_widget_get_parent_window (widget);
+  gtk_widget_set_window (widget, window);
+  g_object_ref (window);
 
   priv->event_window = gdk_window_new (gtk_widget_get_parent_window (widget),
 				       &attributes, attributes_mask);
   gdk_window_set_user_data (priv->event_window, widget);
 
-  widget->style = gtk_style_attach (widget->style, widget->window);
+  gtk_widget_style_attach (widget);
 }
 
 static void
@@ -497,6 +500,7 @@ static void
 get_expander_bounds (GtkExpander  *expander,
 		     GdkRectangle *rect)
 {
+  GtkAllocation allocation;
   GtkWidget *widget;
   GtkExpanderPrivate *priv;
   gint border_width;
@@ -510,6 +514,8 @@ get_expander_bounds (GtkExpander  *expander,
   widget = GTK_WIDGET (expander);
   priv = expander->priv;
 
+  gtk_widget_get_allocation (widget, &allocation);
+
   border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
   gtk_widget_style_get (widget,
@@ -522,20 +528,20 @@ get_expander_bounds (GtkExpander  *expander,
 
   ltr = gtk_widget_get_direction (widget) != GTK_TEXT_DIR_RTL;
 
-  rect->x = widget->allocation.x + border_width;
-  rect->y = widget->allocation.y + border_width;
+  rect->x = allocation.x + border_width;
+  rect->y = allocation.y + border_width;
 
   if (ltr)
     rect->x += expander_spacing;
   else
-    rect->x += widget->allocation.width - 2 * border_width -
+    rect->x += allocation.width - 2 * border_width -
                expander_spacing - expander_size;
 
   if (priv->label_widget && gtk_widget_get_visible (priv->label_widget))
     {
       GtkAllocation label_allocation;
 
-      label_allocation = priv->label_widget->allocation;
+      gtk_widget_get_allocation (priv->label_widget, &label_allocation);
 
       if (expander_size < label_allocation.height)
 	rect->y += focus_width + focus_pad + (label_allocation.height - expander_size) / 2;
@@ -583,7 +589,7 @@ gtk_expander_size_allocate (GtkWidget     *widget,
 
   border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
 
-  widget->allocation = *allocation;
+  gtk_widget_set_allocation (widget, allocation);
 
   gtk_widget_style_get (widget,
 			"interior-focus", &interior_focus,
@@ -602,7 +608,7 @@ gtk_expander_size_allocate (GtkWidget     *widget,
   child_ypad     = 2 * border_width + priv->spacing + (interior_focus ? 0 : 2 * focus_width + 2 * focus_pad);
   top_min_height = 2 * expander_spacing + expander_size;
 
-  child_visible = (child && GTK_WIDGET_CHILD_VISIBLE (child));
+  child_visible = (child && gtk_widget_get_child_visible (child));
 
   if (priv->label_widget && gtk_widget_get_visible (priv->label_widget))
     {
@@ -610,7 +616,7 @@ gtk_expander_size_allocate (GtkWidget     *widget,
       gint          natural_label_width;
       gboolean ltr;
 
-      gtk_size_request_get_width (GTK_SIZE_REQUEST (priv->label_widget), NULL, &natural_label_width);
+      gtk_widget_get_preferred_width (priv->label_widget, NULL, &natural_label_width);
 
       if (priv->label_fill)
         label_allocation.width = allocation->width - label_xpad;
@@ -620,21 +626,20 @@ gtk_expander_size_allocate (GtkWidget     *widget,
 
       /* We distribute the minimum height to the label widget and prioritize
        * the child widget giving it the remaining height */
-      gtk_size_request_get_height_for_width (GTK_SIZE_REQUEST (priv->label_widget),
-					     label_allocation.width, &label_height, NULL);
+      gtk_widget_get_preferred_height_for_width (priv->label_widget,
+                                                 label_allocation.width, &label_height, NULL);
 
       ltr = gtk_widget_get_direction (widget) != GTK_TEXT_DIR_RTL;
 
       if (priv->label_fill)
-        label_allocation.x = widget->allocation.x + label_xoffset;
+        label_allocation.x = allocation->x + label_xoffset;
       else if (ltr)
-        label_allocation.x = widget->allocation.x + label_xoffset;
+        label_allocation.x = allocation->x + label_xoffset;
       else
-        label_allocation.x =
-          widget->allocation.x + widget->allocation.width -
-          (label_allocation.width + label_xoffset);
+        label_allocation.x = allocation->x + allocation->width -
+                             (label_allocation.width + label_xoffset);
 
-      label_allocation.y = widget->allocation.y + border_width + focus_width + focus_pad;
+      label_allocation.y = allocation->y + border_width + focus_width + focus_pad;
       label_allocation.height = MIN (label_height,
 				     allocation->height - 2 * border_width -
 				     2 * focus_width - 2 * focus_pad -
@@ -671,8 +676,8 @@ gtk_expander_size_allocate (GtkWidget     *widget,
       top_height = MAX (top_min_height,
 			label_height + (interior_focus ? 2 * focus_width + 2 * focus_pad : 0));
 
-      child_allocation.x = widget->allocation.x + border_width;
-      child_allocation.y = widget->allocation.y + top_height + child_yoffset;
+      child_allocation.x = allocation->x + border_width;
+      child_allocation.y = allocation->y + top_height + child_yoffset;
 
       child_allocation.width = MAX (allocation->width - 2 * border_width, 1);
       child_allocation.height = allocation->height - top_height - child_ypad;
@@ -711,8 +716,9 @@ gtk_expander_unmap (GtkWidget *widget)
 }
 
 static void
-gtk_expander_paint_prelight (GtkExpander *expander)
+gtk_expander_paint_prelight (GtkExpander *expander, cairo_t *cr)
 {
+  GtkAllocation allocation;
   GtkWidget *widget;
   GtkContainer *container;
   GtkExpanderPrivate *priv;
@@ -736,13 +742,20 @@ gtk_expander_paint_prelight (GtkExpander *expander)
 			"expander-spacing", &expander_spacing,
 			NULL);
 
+  gtk_widget_get_allocation (widget, &allocation);
+
   border_width = gtk_container_get_border_width (container);
-  area.x = widget->allocation.x + border_width;
-  area.y = widget->allocation.y + border_width;
-  area.width = widget->allocation.width - (2 * border_width);
+  area.x = border_width;
+  area.y = border_width;
+  area.width = allocation.width - (2 * border_width);
 
   if (priv->label_widget && gtk_widget_get_visible (priv->label_widget))
-    area.height = priv->label_widget->allocation.height;
+    {
+      GtkAllocation label_widget_allocation;
+
+      gtk_widget_get_allocation (priv->label_widget, &label_widget_allocation);
+      area.height = label_widget_allocation.height;
+    }
   else
     area.height = 0;
 
@@ -750,47 +763,49 @@ gtk_expander_paint_prelight (GtkExpander *expander)
   area.height = MAX (area.height, expander_size + 2 * expander_spacing);
   area.height += !interior_focus ? (focus_width + focus_pad) * 2 : 0;
 
-  gtk_paint_flat_box (widget->style, widget->window,
+  gtk_paint_flat_box (gtk_widget_get_style (widget),
+                      cr,
 		      GTK_STATE_PRELIGHT,
 		      GTK_SHADOW_ETCHED_OUT,
-		      &area, widget, "expander",
+		      widget, "expander",
 		      area.x, area.y,
 		      area.width, area.height);
 }
 
 static void
-gtk_expander_paint (GtkExpander *expander)
+gtk_expander_paint (GtkExpander *expander, cairo_t *cr)
 {
   GtkWidget *widget;
   GdkRectangle clip;
+  GtkAllocation allocation;
   GtkStateType state;
 
   widget = GTK_WIDGET (expander);
 
   get_expander_bounds (expander, &clip);
+  gtk_widget_get_allocation (widget, &allocation);
 
-  state = widget->state;
+  state = gtk_widget_get_state (widget);
   if (expander->priv->prelight)
     {
       state = GTK_STATE_PRELIGHT;
 
-      gtk_expander_paint_prelight (expander);
+      gtk_expander_paint_prelight (expander, cr);
     }
 
-  gtk_paint_expander (widget->style,
-		      widget->window,
+  gtk_paint_expander (gtk_widget_get_style (widget),
+		      cr,
 		      state,
-		      &clip,
 		      widget,
 		      "expander",
-		      clip.x + clip.width / 2,
-		      clip.y + clip.height / 2,
+		      clip.x + clip.width / 2 - allocation.x,
+		      clip.y + clip.height / 2 - allocation.y,
 		      expander->priv->expander_style);
 }
 
 static void
-gtk_expander_paint_focus (GtkExpander  *expander,
-			  GdkRectangle *area)
+gtk_expander_paint_focus (GtkExpander *expander,
+			  cairo_t     *cr)
 {
   GtkWidget *widget;
   GtkExpanderPrivate *priv;
@@ -803,11 +818,13 @@ gtk_expander_paint_focus (GtkExpander  *expander,
   gint expander_size;
   gint expander_spacing;
   gboolean ltr;
+  GtkAllocation allocation;
 
   widget = GTK_WIDGET (expander);
   priv = expander->priv;
 
   border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
+  gtk_widget_get_allocation (widget, &allocation);
 
   gtk_widget_style_get (widget,
 			"interior-focus", &interior_focus,
@@ -835,8 +852,8 @@ gtk_expander_paint_focus (GtkExpander  *expander,
       width  += 2 * focus_pad + 2 * focus_width;
       height += 2 * focus_pad + 2 * focus_width;
 
-      x = widget->allocation.x + border_width;
-      y = widget->allocation.y + border_width;
+      x = border_width;
+      y = border_width;
 
       if (ltr)
 	{
@@ -845,7 +862,7 @@ gtk_expander_paint_focus (GtkExpander  *expander,
 	}
       else
 	{
-	  x += widget->allocation.width - 2 * border_width
+	  x += allocation.width - 2 * border_width
 	    - expander_spacing * 2 - expander_size - width;
 	}
 
@@ -859,32 +876,31 @@ gtk_expander_paint_focus (GtkExpander  *expander,
     {
       get_expander_bounds (expander, &rect);
 
-      x = rect.x - focus_pad;
-      y = rect.y - focus_pad;
+      x = rect.x - allocation.x - focus_pad;
+      y = rect.y - allocation.y - focus_pad;
       width = rect.width + 2 * focus_pad;
       height = rect.height + 2 * focus_pad;
     }
-      
-  gtk_paint_focus (widget->style, widget->window, gtk_widget_get_state (widget),
-		   area, widget, "expander",
+
+  gtk_paint_focus (gtk_widget_get_style (widget),
+                   cr,
+                   gtk_widget_get_state (widget),
+		   widget, "expander",
 		   x, y, width, height);
 }
 
 static gboolean
-gtk_expander_expose (GtkWidget      *widget,
-		     GdkEventExpose *event)
+gtk_expander_draw (GtkWidget *widget,
+		   cairo_t   *cr)
 {
-  if (gtk_widget_is_drawable (widget))
-    {
-      GtkExpander *expander = GTK_EXPANDER (widget);
+  GtkExpander *expander = GTK_EXPANDER (widget);
 
-      gtk_expander_paint (expander);
+  gtk_expander_paint (expander, cr);
 
-      if (gtk_widget_has_focus (widget))
-	gtk_expander_paint_focus (expander, &event->area);
+  if (gtk_widget_has_focus (widget))
+    gtk_expander_paint_focus (expander, cr);
 
-      GTK_WIDGET_CLASS (gtk_expander_parent_class)->expose_event (widget, event);
-    }
+  GTK_WIDGET_CLASS (gtk_expander_parent_class)->draw (widget, cr);
 
   return FALSE;
 }
@@ -939,12 +955,14 @@ gtk_expander_state_changed (GtkWidget    *widget,
 static void
 gtk_expander_redraw_expander (GtkExpander *expander)
 {
-  GtkWidget *widget;
-
-  widget = GTK_WIDGET (expander);
+  GtkAllocation allocation;
+  GtkWidget *widget = GTK_WIDGET (expander);
 
   if (gtk_widget_get_realized (widget))
-    gdk_window_invalidate_rect (widget->window, &widget->allocation, FALSE);
+    {
+      gtk_widget_get_allocation (widget, &allocation);
+      gdk_window_invalidate_rect (gtk_widget_get_window (widget), &allocation, FALSE);
+    }
 }
 
 static gboolean
@@ -952,17 +970,16 @@ gtk_expander_enter_notify (GtkWidget        *widget,
 			   GdkEventCrossing *event)
 {
   GtkExpander *expander = GTK_EXPANDER (widget);
-  GtkWidget *event_widget;
 
-  event_widget = gtk_get_event_widget ((GdkEvent *) event);
-
-  if (event_widget == widget &&
+  if (event->window == expander->priv->event_window &&
       event->detail != GDK_NOTIFY_INFERIOR)
     {
       expander->priv->prelight = TRUE;
 
       if (expander->priv->label_widget)
-	gtk_widget_set_state (expander->priv->label_widget, GTK_STATE_PRELIGHT);
+        gtk_widget_set_state_flags (expander->priv->label_widget,
+                                    GTK_STATE_FLAG_PRELIGHT,
+                                    FALSE);
 
       gtk_expander_redraw_expander (expander);
     }
@@ -975,17 +992,15 @@ gtk_expander_leave_notify (GtkWidget        *widget,
 			   GdkEventCrossing *event)
 {
   GtkExpander *expander = GTK_EXPANDER (widget);
-  GtkWidget *event_widget;
 
-  event_widget = gtk_get_event_widget ((GdkEvent *) event);
-
-  if (event_widget == widget &&
+  if (event->window == expander->priv->event_window &&
       event->detail != GDK_NOTIFY_INFERIOR)
     {
       expander->priv->prelight = FALSE;
 
       if (expander->priv->label_widget)
-	gtk_widget_set_state (expander->priv->label_widget, GTK_STATE_NORMAL);
+        gtk_widget_unset_state_flags (expander->priv->label_widget,
+                                      GTK_STATE_FLAG_PRELIGHT);
 
       gtk_expander_redraw_expander (expander);
     }
@@ -1085,7 +1100,7 @@ focus_in_site (GtkExpander      *expander,
       {
 	GtkWidget *child = gtk_bin_get_child (GTK_BIN (expander));
 
-	if (child && GTK_WIDGET_CHILD_VISIBLE (child))
+	if (child && gtk_widget_get_child_visible (child))
 	  return gtk_widget_child_focus (child, direction);
 	else
 	  return FALSE;
@@ -1250,19 +1265,10 @@ gtk_expander_activate (GtkExpander *expander)
 }
 
 
-static void
-gtk_expander_size_request_init (GtkSizeRequestIface *iface)
-{
-  iface->get_width            = gtk_expander_get_width;
-  iface->get_height           = gtk_expander_get_height;
-  iface->get_height_for_width = gtk_expander_get_height_for_width;
-  iface->get_width_for_height = gtk_expander_get_width_for_height;
-}
-
 static void     
-gtk_expander_get_width (GtkSizeRequest      *widget,
-			gint                *minimum_size,
-			gint                *natural_size)
+gtk_expander_get_preferred_width (GtkWidget *widget,
+                                  gint      *minimum_size,
+                                  gint      *natural_size)
 {
   GtkExpander *expander;
   GtkWidget *child;
@@ -1296,19 +1302,19 @@ gtk_expander_get_width (GtkSizeRequest      *widget,
     {
       gint label_min, label_nat;
 
-      gtk_size_request_get_width (GTK_SIZE_REQUEST (priv->label_widget), 
-				  &label_min, &label_nat);
+      gtk_widget_get_preferred_width (priv->label_widget, 
+                                      &label_min, &label_nat);
 
       *minimum_size += label_min;
       *natural_size += label_nat;
     }
 
-  if (child && GTK_WIDGET_CHILD_VISIBLE (child))
+  if (child && gtk_widget_get_child_visible (child))
     {
       gint child_min, child_nat;
 
-      gtk_size_request_get_width (GTK_SIZE_REQUEST (child), 
-				  &child_min, &child_nat);
+      gtk_widget_get_preferred_width (child, 
+                                      &child_min, &child_nat);
 
       *minimum_size = MAX (*minimum_size, child_min);
       *natural_size = MAX (*natural_size, child_nat);
@@ -1320,9 +1326,9 @@ gtk_expander_get_width (GtkSizeRequest      *widget,
 }
 
 static void
-gtk_expander_get_height (GtkSizeRequest      *widget,
-			 gint                *minimum_size,
-			 gint                *natural_size)
+gtk_expander_get_preferred_height (GtkWidget *widget,
+                                   gint      *minimum_size,
+                                   gint      *natural_size)
 {  
   GtkExpander *expander;
   GtkWidget *child;
@@ -1356,8 +1362,8 @@ gtk_expander_get_height (GtkSizeRequest      *widget,
     {
       gint label_min, label_nat;
 
-      gtk_size_request_get_height (GTK_SIZE_REQUEST (priv->label_widget), 
-				   &label_min, &label_nat);
+      gtk_widget_get_preferred_height (priv->label_widget, 
+                                       &label_min, &label_nat);
       
       *minimum_size += label_min;
       *natural_size += label_nat;
@@ -1373,12 +1379,12 @@ gtk_expander_get_height (GtkSizeRequest      *widget,
       *natural_size += extra;
     }
 
-  if (child && GTK_WIDGET_CHILD_VISIBLE (child))
+  if (child && gtk_widget_get_child_visible (child))
     {
       gint child_min, child_nat;
 
-      gtk_size_request_get_height (GTK_SIZE_REQUEST (child), 
-				   &child_min, &child_nat);
+      gtk_widget_get_preferred_height (child, 
+                                       &child_min, &child_nat);
 
       *minimum_size += child_min + priv->spacing;
       *natural_size += child_nat + priv->spacing;
@@ -1390,10 +1396,10 @@ gtk_expander_get_height (GtkSizeRequest      *widget,
 }
 
 static void
-gtk_expander_get_height_for_width (GtkSizeRequest *widget,
-				   gint            width,
-				   gint           *minimum_height,
-				   gint           *natural_height)
+gtk_expander_get_preferred_height_for_width (GtkWidget *widget,
+                                             gint       width,
+                                             gint      *minimum_height,
+                                             gint      *natural_height)
 {
   GtkExpander *expander;
   GtkWidget *child;
@@ -1430,9 +1436,9 @@ gtk_expander_get_height_for_width (GtkSizeRequest *widget,
     {
       gint label_min, label_nat;
 
-      gtk_size_request_get_height_for_width (GTK_SIZE_REQUEST (priv->label_widget), 
-					     MAX (width - label_xpad, 1), 
-					     &label_min, &label_nat);
+      gtk_widget_get_preferred_height_for_width (priv->label_widget, 
+                                                 MAX (width - label_xpad, 1), 
+                                                 &label_min, &label_nat);
       
       *minimum_height += label_min;
       *natural_height += label_nat;
@@ -1448,13 +1454,13 @@ gtk_expander_get_height_for_width (GtkSizeRequest *widget,
       *natural_height += extra;
     }
 
-  if (child && GTK_WIDGET_CHILD_VISIBLE (child))
+  if (child && gtk_widget_get_child_visible (child))
     {
       gint child_min, child_nat;
 
-      gtk_size_request_get_height_for_width (GTK_SIZE_REQUEST (child), 
-					     MAX (width - 2 * border_width, 1), 
-					     &child_min, &child_nat);
+      gtk_widget_get_preferred_height_for_width (child, 
+                                                 MAX (width - 2 * border_width, 1), 
+                                                 &child_min, &child_nat);
 
       *minimum_height += child_min + priv->spacing;
       *natural_height += child_nat + priv->spacing;
@@ -1465,13 +1471,12 @@ gtk_expander_get_height_for_width (GtkSizeRequest *widget,
 }
 
 static void
-gtk_expander_get_width_for_height (GtkSizeRequest *widget,
-				   gint       height,
-				   gint      *minimum_width,
-				   gint      *natural_width)
+gtk_expander_get_preferred_width_for_height (GtkWidget *widget,
+                                             gint       height,
+                                             gint      *minimum_width,
+                                             gint      *natural_width)
 {
-  gtk_size_request_get_width (widget, minimum_width, natural_width);
-  //GTK_SIZE_REQUEST_GET_IFACE (widget)->get_width (widget, minimum_width, natural_width);
+  GTK_WIDGET_GET_CLASS (widget)->get_preferred_width (widget, minimum_width, natural_width);
 }
 
 
@@ -1521,14 +1526,15 @@ static gboolean
 gtk_expander_animation_timeout (GtkExpander *expander)
 {
   GtkExpanderPrivate *priv = expander->priv;
+  GtkWidget *widget = GTK_WIDGET (expander);
   GtkWidget *child;
   GdkRectangle area;
   gboolean finish = FALSE;
 
-  if (gtk_widget_get_realized (GTK_WIDGET (expander)))
+  if (gtk_widget_get_realized (widget))
     {
       get_expander_bounds (expander, &area);
-      gdk_window_invalidate_rect (GTK_WIDGET (expander)->window, &area, TRUE);
+      gdk_window_invalidate_rect (gtk_widget_get_window (widget), &area, TRUE);
     }
 
   if (priv->expanded)
@@ -1563,7 +1569,7 @@ gtk_expander_animation_timeout (GtkExpander *expander)
       child = gtk_bin_get_child (GTK_BIN (expander));
       if (child)
 	gtk_widget_set_child_visible (child, priv->expanded);
-      gtk_widget_queue_resize (GTK_WIDGET (expander));
+      gtk_widget_queue_resize (widget);
     }
 
   return !finish;
@@ -1901,7 +1907,7 @@ gtk_expander_set_label_widget (GtkExpander *expander,
 
   g_return_if_fail (GTK_IS_EXPANDER (expander));
   g_return_if_fail (label_widget == NULL || GTK_IS_WIDGET (label_widget));
-  g_return_if_fail (label_widget == NULL || label_widget->parent == NULL);
+  g_return_if_fail (label_widget == NULL || gtk_widget_get_parent (label_widget) == NULL);
 
   priv = expander->priv;
 
@@ -1910,7 +1916,7 @@ gtk_expander_set_label_widget (GtkExpander *expander,
 
   if (priv->label_widget)
     {
-      gtk_widget_set_state (priv->label_widget, GTK_STATE_NORMAL);
+      gtk_widget_set_state_flags (priv->label_widget, 0, TRUE);
       gtk_widget_unparent (priv->label_widget);
     }
 
@@ -1924,7 +1930,9 @@ gtk_expander_set_label_widget (GtkExpander *expander,
       gtk_widget_set_parent (label_widget, widget);
 
       if (priv->prelight)
-	gtk_widget_set_state (label_widget, GTK_STATE_PRELIGHT);
+	gtk_widget_set_state_flags (label_widget,
+                                    GTK_STATE_FLAG_PRELIGHT,
+                                    FALSE);
     }
 
   if (gtk_widget_get_visible (widget))
@@ -1943,8 +1951,9 @@ gtk_expander_set_label_widget (GtkExpander *expander,
  * Retrieves the label widget for the frame. See
  * gtk_expander_set_label_widget().
  *
- * Return value: the label widget, or %NULL if there is none.
- * 
+ * Return value: (transfer none): the label widget,
+ *     or %NULL if there is none.
+ *
  * Since: 2.4
  **/
 GtkWidget *
