@@ -105,29 +105,6 @@ get_cached_size (SizeRequestCache  *cache,
 }
 
 
-extern guint _size_request_signal_id;
-static void
-do_size_request (GtkWidget      *widget,
-		 GtkRequisition *requisition)
-{
-  GtkWidgetClass *widget_class = g_type_class_peek (GTK_TYPE_WIDGET);
-
-  if (GTK_WIDGET_GET_CLASS (widget)->size_request != widget_class->size_request)
-    g_warning ("%s implements GtkWidgetClass::size_request which is deprecated and "
-	       "will be removed in the next release",
-	       G_OBJECT_TYPE_NAME (widget));
-
-  if (g_signal_has_handler_pending (widget, _size_request_signal_id, 0, TRUE))
-    g_warning ("A %s (%p) has handler(s) connected to the GtkWidgetClass::size-request signal which is "
-	       "deprecated and will be removed in the next release",
-	       G_OBJECT_TYPE_NAME (widget), widget);
-
-  /* Now we dont bother caching the deprecated "size-request" returns,
-   * just unconditionally invoke here just in case we run into legacy stuff */
-  gtk_widget_ensure_style (widget);
-  g_signal_emit_by_name (widget, "size-request", requisition);
-}
-
 #ifndef G_DISABLE_CHECKS
 static GQuark recursion_check_quark = 0;
 #endif /* G_DISABLE_CHECKS */
@@ -225,17 +202,13 @@ compute_size_for_orientation (GtkWidget         *widget,
 
   if (!found_in_cache)
     {
-      GtkRequisition requisition = { 0, 0 };
-      gint min_size = 0, nat_size = 0;
-      gint requisition_size;
+      gint min_size = 0;
+      gint nat_size = 0;
 
-      /* Unconditional size request runs but is often unhandled. */
-      do_size_request (widget, &requisition);
+      gtk_widget_ensure_style (widget);
 
       if (orientation == GTK_SIZE_GROUP_HORIZONTAL)
         {
-          requisition_size = requisition.width;
-
           if (for_size < 0)
             {
 	      push_recursion_check (widget, orientation, for_size);
@@ -247,7 +220,7 @@ compute_size_for_orientation (GtkWidget         *widget,
               int ignored_position = 0;
               int natural_height;
 
-	      /* Pull the base natural height from the cache as it's needed to adjust 
+	      /* Pull the base natural height from the cache as it's needed to adjust
 	       * the proposed 'for_size' */
 	      gtk_widget_get_preferred_height (widget, NULL, &natural_height);
 
@@ -266,8 +239,6 @@ compute_size_for_orientation (GtkWidget         *widget,
         }
       else
         {
-          requisition_size = requisition.height;
-
           if (for_size < 0)
             {
 	      push_recursion_check (widget, orientation, for_size);
@@ -279,7 +250,7 @@ compute_size_for_orientation (GtkWidget         *widget,
               int ignored_position = 0;
               int natural_width;
 
-	      /* Pull the base natural width from the cache as it's needed to adjust 
+	      /* Pull the base natural width from the cache as it's needed to adjust
 	       * the proposed 'for_size' */
 	      gtk_widget_get_preferred_width (widget, NULL, &natural_width);
 
@@ -303,12 +274,6 @@ compute_size_for_orientation (GtkWidget         *widget,
                      G_OBJECT_TYPE_NAME (widget), widget, min_size, nat_size);
         }
 
-      /* Support for dangling "size-request" signal implementations on
-       * legacy widgets
-       */
-      min_size = MAX (min_size, requisition_size);
-      nat_size = MAX (nat_size, requisition_size);
-
       cached_size->minimum_size = min_size;
       cached_size->natural_size = nat_size;
       cached_size->for_size     = for_size;
@@ -353,7 +318,7 @@ compute_size_for_orientation (GtkWidget         *widget,
           cached_size->natural_size = adjusted_natural;
         }
 
-      /* Update size-groups with our request and update our cached requests 
+      /* Update size-groups with our request and update our cached requests
        * with the size-group values in a single pass.
        */
       _gtk_size_group_bump_requisition (widget,
@@ -426,7 +391,7 @@ gtk_widget_get_request_mode (GtkWidget *widget)
  *
  * The returned request will be modified by the
  * GtkWidgetClass::adjust_size_request virtual method and by any
- * #GtkSizeGroup that have been applied. That is, the returned request
+ * #GtkSizeGroup<!-- -->s that have been applied. That is, the returned request
  * is the one that should be used for layout, not necessarily the one
  * returned by the widget itself.
  *
@@ -454,7 +419,7 @@ gtk_widget_get_preferred_width (GtkWidget *widget,
  *
  * The returned request will be modified by the
  * GtkWidgetClass::adjust_size_request virtual method and by any
- * #GtkSizeGroup that have been applied. That is, the returned request
+ * #GtkSizeGroup<!-- -->s that have been applied. That is, the returned request
  * is the one that should be used for layout, not necessarily the one
  * returned by the widget itself.
  *
@@ -483,7 +448,7 @@ gtk_widget_get_preferred_height (GtkWidget *widget,
  *
  * The returned request will be modified by the
  * GtkWidgetClass::adjust_size_request virtual method and by any
- * #GtkSizeGroup that have been applied. That is, the returned request
+ * #GtkSizeGroup<!-- -->s that have been applied. That is, the returned request
  * is the one that should be used for layout, not necessarily the one
  * returned by the widget itself.
  *
@@ -511,7 +476,7 @@ gtk_widget_get_preferred_width_for_height (GtkWidget *widget,
  *
  * The returned request will be modified by the
  * GtkWidgetClass::adjust_size_request virtual method and by any
- * #GtkSizeGroup that have been applied. That is, the returned request
+ * #GtkSizeGroup<!-- -->s that have been applied. That is, the returned request
  * is the one that should be used for layout, not necessarily the one
  * returned by the widget itself.
  *
@@ -533,15 +498,15 @@ gtk_widget_get_preferred_height_for_width (GtkWidget *widget,
  * @minimum_size: (out) (allow-none): location for storing the minimum size, or %NULL
  * @natural_size: (out) (allow-none): location for storing the natural size, or %NULL
  *
- * Retrieves the minimum and natural size of a widget taking
+ * Retrieves the minimum and natural size of a widget, taking
  * into account the widget's preference for height-for-width management.
  *
  * This is used to retrieve a suitable size by container widgets which do
  * not impose any restrictions on the child placement. It can be used
  * to deduce toplevel window and menu sizes as well as child widgets in
- * free form containers such as GtkLayout.
+ * free-form containers such as GtkLayout.
  *
- * <note><para>Handle with care, note that the natural height of a height-for-width
+ * <note><para>Handle with care. Note that the natural height of a height-for-width
  * widget will generally be a smaller size than the minimum height, since the required
  * height for the natural width is generally smaller than the required height for
  * the minimum width.</para></note>
@@ -622,14 +587,14 @@ compare_gap (gconstpointer p1,
 }
 
 /**
- * gtk_distribute_natural_allocation: 
+ * gtk_distribute_natural_allocation:
  * @extra_space: Extra space to redistribute among children after subtracting
  *               minimum sizes and any child padding from the overall allocation
  * @n_requested_sizes: Number of requests to fit into the allocation
  * @sizes: An array of structs with a client pointer and a minimum/natural size
  *         in the orientation of the allocation.
  *
- * Distributes @extra_space to child @sizes by bringing up smaller
+ * Distributes @extra_space to child @sizes by bringing smaller
  * children up to natural size first.
  *
  * The remaining space will be added to the @minimum_size member of the
@@ -639,7 +604,7 @@ compare_gap (gconstpointer p1,
  * Returns: The remainder of @extra_space after redistributing space
  * to @sizes.
  */
-gint 
+gint
 gtk_distribute_natural_allocation (gint              extra_space,
 				   guint             n_requested_sizes,
 				   GtkRequestedSize *sizes)
@@ -670,12 +635,12 @@ gtk_distribute_natural_allocation (gint              extra_space,
    * The following code distributes the additional space by following
    * these rules.
    */
-  
+
   /* Sort descending by gap and position. */
   g_qsort_with_data (spreading,
 		     n_requested_sizes, sizeof (guint),
 		     compare_gap, sizes);
-  
+
   /* Distribute available space.
    * This master piece of a loop was conceived by Behdad Esfahbod.
    */
@@ -688,14 +653,13 @@ gtk_distribute_natural_allocation (gint              extra_space,
       gint glue = (extra_space + i) / (i + 1);
       gint gap = sizes[(spreading[i])].natural_size
 	- sizes[(spreading[i])].minimum_size;
-      
+
       gint extra = MIN (glue, gap);
-      
+
       sizes[spreading[i]].minimum_size += extra;
-      
+
       extra_space -= extra;
     }
 
   return extra_space;
 }
-
